# noinspection PyUnresolvedReferences
from .dir import *
# noinspection PyUnresolvedReferences
from .geom import *
# noinspection PyUnresolvedReferences
from .ops import *
# noinspection PyUnresolvedReferences
from .settings import *
# noinspection PyUnresolvedReferences
from .sql import *
# noinspection PyUnresolvedReferences
from .store import *
# noinspection PyUnresolvedReferences
from .text import *

__package_name__ = 'pyhelpers'
__package_name_alt__ = 'PyHelpers'
__author__ = u'Qian Fu'
__version__ = '1.2.11'
__email__ = 'qian.fu@outlook.com'
__description__ = 'An open-source toolkit designed as a miscellaneous collection of simple ' \
                  'and useful Python tools for facilitating data manipulation tasks.'
